.. _ide-integration:

###########################
 Editor and IDE integration
###########################

Pylint can be integrated in various editors and IDE's.
Below you can find tutorials for some of the most common ones.

- Eclipse_
- Emacs_
- `Eric IDE`_ in the `Project > Check` menu,
- gedit_ (`another option for gedit`_)
- :ref:`Flymake <pylint_in_flymake>`
- `Jupyter Notebook`_
- Komodo_
- `Pycharm`_
- PyDev_
- pyscripter_ in the `Tool -> Tools` menu.
- Spyder_ in the `View -> Panes -> Static code analysis`
- `Sublime Text`_
- :ref:`TextMate <pylint_in_textmate>`
- Vim_
- `Visual Studio Code`_ in the `Preferences -> Settings` menu
- `Visual Studio Code Pylint Extension`_
- `Visual Studio`_ in the `Python > Run PyLint` command on a project's context menu.
- WingIDE_

.. _Eclipse: https://www.pydev.org/manual_adv_pylint.html
.. _Emacs: https://www.emacswiki.org/emacs/PythonProgrammingInEmacs
.. _Eric IDE: https://eric-ide.python-projects.org/
.. _gedit: https://launchpad.net/gedit-pylint-2
.. _another option for gedit: https://wiki.gnome.org/Apps/Gedit/PylintPlugin
.. _Jupyter Notebook:  https://github.com/nbQA-dev/nbQA
.. _Komodo: https://mateusz.loskot.net/post/2006/01/15/running-pylint-from-komodo/
.. _Pycharm: https://stackoverflow.com/a/46409649/2519059
.. _pydev: https://www.pydev.org/manual_adv_pylint.html
.. _pyscripter: https://github.com/pyscripter/pyscripter
.. _spyder: https://docs.spyder-ide.org/current/panes/pylint.html
.. _Sublime Text: https://packagecontrol.io/packages/SublimeLinter-pylint
.. _Vim: https://www.vim.org/scripts/script.php?script_id=891
.. _Visual Studio: https://docs.microsoft.com/visualstudio/python/code-pylint
.. _Visual Studio Code: https://code.visualstudio.com/docs/python/linting
.. _Visual Studio Code Pylint Extension: https://marketplace.visualstudio.com/items?itemName=ms-python.pylint
.. _WingIDE: https://wingware.com/doc/warnings/external-checkers

.. toctree::
   :maxdepth: 2
   :titlesonly:
   :hidden:

   flymake-emacs.rst
   textmate.rst
